function [newNode,currentErr] = tiltShiftSubspace(node,vt,obsInd,method,alpha,eta)

% alpha: forgetting factor
% eta: the stepsize for GROUSE

d = size(node.basis,2);
D = length(vt);
c_old = node.center;
U_old = node.basis;
spread_old = node.spread;
deviate_old = node.deviate;
error_old = node.error;

centerSub = vt-c_old;
w = U_old(obsInd,:)\centerSub(obsInd);
res = centerSub(obsInd)-U_old(obsInd,:)*w;
currentErr = norm(res)^2; % for anomaly detection

newNode = node;

%% use subspace tracking algorithm for basis update
switch method
    case 'grouse'
        U_new = grouse(centerSub,obsInd,eta,U_old);
    case 'petrels_gs'
        [U_new,R_new] = petrels(centerSub,obsInd,alpha,U_old,node.R);
        newNode.R = R_new;
        U_new = orth(U_new);
    case 'petrels_fo'
        [U_new,R_new,~] = OPAST(centerSub,obsInd,alpha,U_old,node.R);
        newNode.R = R_new;
end

%%
c_new = c_old;
c_new(obsInd) = c_old(obsInd)*alpha+vt(obsInd)*(1-alpha);
centerSub = vt(obsInd)-c_new(obsInd);
w = U_new(obsInd,:)\centerSub;
spread_new = spread_old*alpha + w.^2*(1-alpha);
r = centerSub-U_new(obsInd,:)*w;
deviate_new = deviate_old*alpha + norm(r)^2/(D-d)*(1-alpha);
%error_new = error_old*(1-lambda) + norm(r)^2/(norm(centerSub)^2+eps)*lambda;
error_new = error_old*alpha + norm(r)^2*(1-alpha);

newNode.basis = U_new;
newNode.center = c_new;
newNode.spread = spread_new;
newNode.deviate = deviate_new;
newNode.error = error_new;
